# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from typing import Union, Tuple
from hidet.ir.expr import Expr


Int = Union[Expr, int]
Dim3 = Union[Int, Tuple[Int, Int], Tuple[Int, Int, Int]]

# The grid dimension of a hip kernel, specifying the number of thread blocks
grid_dim: Dim3 = 1

# The block dimension of a hip kernel, specifying the number of threads per block
block_dim: Dim3 = 1

# The dynamic shared memory size of a hip kernel, in bytes
dynamic_smem_bytes: int = 0
